@@ -2,10 +2,12 @@
 
 __author__ = """yinochaos"""
 __email__ = 'pspcxl@163.com'
-__version__ = '0.0.1'
+__version__ = '0.0.16'
 
-__all__ = ['DataSchema', 'data_processor_dicts', 'TokenDicts', 'RawDataset', 'TextlineParser', 'TFDataset', 'PTDataset']
+__all__ = ['DataSchema', 'data_processor_dicts', 'TokenDicts', 'TextlineParser', 'SeqParser', 'TFDataset']
+#__all__ = ['DataSchema', 'data_processor_dicts', 'TokenDicts', 'TextlineParser', 'SeqParser', 'TFDataset', 'PTDataset']
 from datasets.textline_parser import TextlineParser
+from datasets.seq_parser import SeqParser
 from datasets.tf_dataset import TFDataset
 #from datasets.pt_dataset import PTDataset
 from datasets.utils import DataSchema, data_processor_dicts, TokenDicts
